Class: Google::Apis::SpeechV1::LongRunningRecognizeMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpeechV1::LongRunningRecognizeMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/speech_v1/classes.rb,
lib/google/apis/speech_v1/representations.rb,
lib/google/apis/speech_v1/representations.rb
Overview
Describes the progress of a long-running LongRunningRecognize call. It is
included in the metadata field of the Operation returned by the
GetOperation call of the google::longrunning::Operations service.
Instance Attribute Summary collapse
-
#last_update_time ⇒ String
Time of the most recent processing update.
-
#progress_percent ⇒ Fixnum
Approximate percentage of audio processed thus far.
-
#start_time ⇒ String
Time when the request was received.
-
#uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LongRunningRecognizeMetadata
constructor
A new instance of LongRunningRecognizeMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LongRunningRecognizeMetadata
Returns a new instance of LongRunningRecognizeMetadata.
397 398 399 |
# File 'lib/google/apis/speech_v1/classes.rb', line 397 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_update_time ⇒ String
Time of the most recent processing update.
Corresponds to the JSON property lastUpdateTime
378 379 380 |
# File 'lib/google/apis/speech_v1/classes.rb', line 378 def last_update_time @last_update_time end |
#progress_percent ⇒ Fixnum
Approximate percentage of audio processed thus far. Guaranteed to be 100 when
the audio is fully processed and the results are available.
Corresponds to the JSON property progressPercent
384 385 386 |
# File 'lib/google/apis/speech_v1/classes.rb', line 384 def progress_percent @progress_percent end |
#start_time ⇒ String
Time when the request was received.
Corresponds to the JSON property startTime
389 390 391 |
# File 'lib/google/apis/speech_v1/classes.rb', line 389 def start_time @start_time end |
#uri ⇒ String
Output only. The URI of the audio file being transcribed. Empty if the audio
was sent as byte content.
Corresponds to the JSON property uri
395 396 397 |
# File 'lib/google/apis/speech_v1/classes.rb', line 395 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
402 403 404 405 406 407 |
# File 'lib/google/apis/speech_v1/classes.rb', line 402 def update!(**args) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @progress_percent = args[:progress_percent] if args.key?(:progress_percent) @start_time = args[:start_time] if args.key?(:start_time) @uri = args[:uri] if args.key?(:uri) end |