Class: Google::Apis::SpeechV1::LongRunningRecognizeResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/speech_v1/classes.rb,
lib/google/apis/speech_v1/representations.rb,
lib/google/apis/speech_v1/representations.rb

Overview

The only message returned to the client by the LongRunningRecognize method. It contains the result as zero or more sequential SpeechRecognitionResult messages. It is included in the result.response field of the Operation returned by the GetOperation call of the google::longrunning::Operations service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LongRunningRecognizeResponse

Returns a new instance of LongRunningRecognizeResponse.



490
491
492
# File 'lib/google/apis/speech_v1/classes.rb', line 490

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#output_configGoogle::Apis::SpeechV1::TranscriptOutputConfig

Specifies an optional destination for the recognition results. Corresponds to the JSON property outputConfig



456
457
458
# File 'lib/google/apis/speech_v1/classes.rb', line 456

def output_config
  @output_config
end

#output_errorGoogle::Apis::SpeechV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property outputError



466
467
468
# File 'lib/google/apis/speech_v1/classes.rb', line 466

def output_error
  @output_error
end

#request_idFixnum

The ID associated with the request. This is a unique ID specific only to the given request. Corresponds to the JSON property requestId

Returns:

  • (Fixnum)


472
473
474
# File 'lib/google/apis/speech_v1/classes.rb', line 472

def request_id
  @request_id
end

#resultsArray<Google::Apis::SpeechV1::SpeechRecognitionResult>

Sequential list of transcription results corresponding to sequential portions of audio. Corresponds to the JSON property results



478
479
480
# File 'lib/google/apis/speech_v1/classes.rb', line 478

def results
  @results
end

#speech_adaptation_infoGoogle::Apis::SpeechV1::SpeechAdaptationInfo

Information on speech adaptation use in results Corresponds to the JSON property speechAdaptationInfo



483
484
485
# File 'lib/google/apis/speech_v1/classes.rb', line 483

def speech_adaptation_info
  @speech_adaptation_info
end

#total_billed_timeString

When available, billed audio seconds for the corresponding request. Corresponds to the JSON property totalBilledTime

Returns:

  • (String)


488
489
490
# File 'lib/google/apis/speech_v1/classes.rb', line 488

def total_billed_time
  @total_billed_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



495
496
497
498
499
500
501
502
# File 'lib/google/apis/speech_v1/classes.rb', line 495

def update!(**args)
  @output_config = args[:output_config] if args.key?(:output_config)
  @output_error = args[:output_error] if args.key?(:output_error)
  @request_id = args[:request_id] if args.key?(:request_id)
  @results = args[:results] if args.key?(:results)
  @speech_adaptation_info = args[:speech_adaptation_info] if args.key?(:speech_adaptation_info)
  @total_billed_time = args[:total_billed_time] if args.key?(:total_billed_time)
end