Class: Google::Apis::SpeechV1::RecognitionConfig
- Inherits:
-
Object
- Object
- Google::Apis::SpeechV1::RecognitionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/speech_v1/classes.rb,
lib/google/apis/speech_v1/representations.rb,
lib/google/apis/speech_v1/representations.rb
Overview
Provides information to the recognizer that specifies how to process the request.
Instance Attribute Summary collapse
-
#adaptation ⇒ Google::Apis::SpeechV1::SpeechAdaptation
Speech adaptation configuration.
-
#alternative_language_codes ⇒ Array<String>
A list of up to 3 additional BCP-47 language tags, listing possible alternative languages of the supplied audio.
-
#audio_channel_count ⇒ Fixnum
The number of channels in the input audio data.
-
#diarization_config ⇒ Google::Apis::SpeechV1::SpeakerDiarizationConfig
Config to enable speaker diarization.
-
#enable_automatic_punctuation ⇒ Boolean
(also: #enable_automatic_punctuation?)
If 'true', adds punctuation to recognition result hypotheses.
-
#enable_separate_recognition_per_channel ⇒ Boolean
(also: #enable_separate_recognition_per_channel?)
This needs to be set to
trueexplicitly andaudio_channel_count> 1 to get each channel recognized separately. -
#enable_spoken_emojis ⇒ Boolean
(also: #enable_spoken_emojis?)
The spoken emoji behavior for the call If not set, uses default behavior based on model of choice If 'true', adds spoken emoji formatting for the request.
-
#enable_spoken_punctuation ⇒ Boolean
(also: #enable_spoken_punctuation?)
The spoken punctuation behavior for the call If not set, uses default behavior based on model of choice e.g.
-
#enable_word_confidence ⇒ Boolean
(also: #enable_word_confidence?)
If
true, the top result includes a list of words and the confidence for those words. -
#enable_word_time_offsets ⇒ Boolean
(also: #enable_word_time_offsets?)
If
true, the top result includes a list of words and the start and end time offsets (timestamps) for those words. -
#encoding ⇒ String
Encoding of audio data sent in all
RecognitionAudiomessages. -
#language_code ⇒ String
Required.
-
#max_alternatives ⇒ Fixnum
Maximum number of recognition hypotheses to be returned.
-
#metadata ⇒ Google::Apis::SpeechV1::RecognitionMetadata
Description of audio data to be recognized.
-
#model ⇒ String
Which model to select for the given request.
-
#profanity_filter ⇒ Boolean
(also: #profanity_filter?)
If set to
true, the server will attempt to filter out profanities, replacing all but the initial character in each filtered word with asterisks, e.g. -
#sample_rate_hertz ⇒ Fixnum
Sample rate in Hertz of the audio data sent in all
RecognitionAudiomessages. -
#speech_contexts ⇒ Array<Google::Apis::SpeechV1::SpeechContext>
Array of SpeechContext.
-
#transcript_normalization ⇒ Google::Apis::SpeechV1::TranscriptNormalization
Transcription normalization configuration.
-
#use_enhanced ⇒ Boolean
(also: #use_enhanced?)
Set to true to use an enhanced model for speech recognition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecognitionConfig
constructor
A new instance of RecognitionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecognitionConfig
Returns a new instance of RecognitionConfig.
960 961 962 |
# File 'lib/google/apis/speech_v1/classes.rb', line 960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adaptation ⇒ Google::Apis::SpeechV1::SpeechAdaptation
Speech adaptation configuration.
Corresponds to the JSON property adaptation
781 782 783 |
# File 'lib/google/apis/speech_v1/classes.rb', line 781 def adaptation @adaptation end |
#alternative_language_codes ⇒ Array<String>
A list of up to 3 additional BCP-47 language tags, listing possible alternative languages of the supplied
audio. See Language Support for a list of the currently supported language codes. If
alternative languages are listed, recognition result will contain recognition
in the most likely language detected including the main language_code. The
recognition result will include the language tag of the language detected in
the audio. Note: This feature is only supported for Voice Command and Voice
Search use cases and performance may vary for other use cases (e.g., phone
call transcription).
Corresponds to the JSON property alternativeLanguageCodes
795 796 797 |
# File 'lib/google/apis/speech_v1/classes.rb', line 795 def alternative_language_codes @alternative_language_codes end |
#audio_channel_count ⇒ Fixnum
The number of channels in the input audio data. ONLY set this for MULTI-
CHANNEL recognition. Valid values for LINEAR16, OGG_OPUS and FLAC are 1-8.
Valid value for MULAW, AMR, AMR_WB and SPEEX_WITH_HEADER_BYTE is only 1. If
0 or omitted, defaults to one channel (mono). Note: We only recognize the
first channel by default. To perform independent recognition on each channel
set enable_separate_recognition_per_channel to 'true'.
Corresponds to the JSON property audioChannelCount
805 806 807 |
# File 'lib/google/apis/speech_v1/classes.rb', line 805 def audio_channel_count @audio_channel_count end |
#diarization_config ⇒ Google::Apis::SpeechV1::SpeakerDiarizationConfig
Config to enable speaker diarization.
Corresponds to the JSON property diarizationConfig
810 811 812 |
# File 'lib/google/apis/speech_v1/classes.rb', line 810 def diarization_config @diarization_config end |
#enable_automatic_punctuation ⇒ Boolean Also known as: enable_automatic_punctuation?
If 'true', adds punctuation to recognition result hypotheses. This feature is
only available in select languages. Setting this for requests in other
languages has no effect at all. The default 'false' value does not add
punctuation to result hypotheses.
Corresponds to the JSON property enableAutomaticPunctuation
818 819 820 |
# File 'lib/google/apis/speech_v1/classes.rb', line 818 def enable_automatic_punctuation @enable_automatic_punctuation end |
#enable_separate_recognition_per_channel ⇒ Boolean Also known as: enable_separate_recognition_per_channel?
This needs to be set to true explicitly and audio_channel_count > 1 to get
each channel recognized separately. The recognition result will contain a
channel_tag field to state which channel that result belongs to. If this is
not true, we will only recognize the first channel. The request is billed
cumulatively for all channels recognized: audio_channel_count multiplied by
the length of the audio.
Corresponds to the JSON property enableSeparateRecognitionPerChannel
829 830 831 |
# File 'lib/google/apis/speech_v1/classes.rb', line 829 def enable_separate_recognition_per_channel @enable_separate_recognition_per_channel end |
#enable_spoken_emojis ⇒ Boolean Also known as: enable_spoken_emojis?
The spoken emoji behavior for the call If not set, uses default behavior based
on model of choice If 'true', adds spoken emoji formatting for the request.
This will replace spoken emojis with the corresponding Unicode symbols in the
final transcript. If 'false', spoken emojis are not replaced.
Corresponds to the JSON property enableSpokenEmojis
838 839 840 |
# File 'lib/google/apis/speech_v1/classes.rb', line 838 def enable_spoken_emojis @enable_spoken_emojis end |
#enable_spoken_punctuation ⇒ Boolean Also known as: enable_spoken_punctuation?
The spoken punctuation behavior for the call If not set, uses default behavior
based on model of choice e.g. command_and_search will enable spoken
punctuation by default If 'true', replaces spoken punctuation with the
corresponding symbols in the request. For example, "how are you question mark"
becomes "how are you?". See https://cloud.google.com/speech-to-text/docs/
spoken-punctuation for support. If 'false', spoken punctuation is not replaced.
Corresponds to the JSON property enableSpokenPunctuation
849 850 851 |
# File 'lib/google/apis/speech_v1/classes.rb', line 849 def enable_spoken_punctuation @enable_spoken_punctuation end |
#enable_word_confidence ⇒ Boolean Also known as: enable_word_confidence?
If true, the top result includes a list of words and the confidence for
those words. If false, no word-level confidence information is returned. The
default is false.
Corresponds to the JSON property enableWordConfidence
857 858 859 |
# File 'lib/google/apis/speech_v1/classes.rb', line 857 def enable_word_confidence @enable_word_confidence end |
#enable_word_time_offsets ⇒ Boolean Also known as: enable_word_time_offsets?
If true, the top result includes a list of words and the start and end time
offsets (timestamps) for those words. If false, no word-level time offset
information is returned. The default is false.
Corresponds to the JSON property enableWordTimeOffsets
865 866 867 |
# File 'lib/google/apis/speech_v1/classes.rb', line 865 def enable_word_time_offsets @enable_word_time_offsets end |
#encoding ⇒ String
Encoding of audio data sent in all RecognitionAudio messages. This field is
optional for FLAC and WAV audio files and required for all other audio
formats. For details, see AudioEncoding.
Corresponds to the JSON property encoding
873 874 875 |
# File 'lib/google/apis/speech_v1/classes.rb', line 873 def encoding @encoding end |
#language_code ⇒ String
Required. The language of the supplied audio as a BCP-47 language tag. Example: "en-US". See Language
Support for a list of
the currently supported language codes.
Corresponds to the JSON property languageCode
881 882 883 |
# File 'lib/google/apis/speech_v1/classes.rb', line 881 def language_code @language_code end |
#max_alternatives ⇒ Fixnum
Maximum number of recognition hypotheses to be returned. Specifically, the
maximum number of SpeechRecognitionAlternative messages within each
SpeechRecognitionResult. The server may return fewer than max_alternatives.
Valid values are 0-30. A value of 0 or 1 will return a maximum of one.
If omitted, will return a maximum of one.
Corresponds to the JSON property maxAlternatives
890 891 892 |
# File 'lib/google/apis/speech_v1/classes.rb', line 890 def max_alternatives @max_alternatives end |
#metadata ⇒ Google::Apis::SpeechV1::RecognitionMetadata
Description of audio data to be recognized.
Corresponds to the JSON property metadata
895 896 897 |
# File 'lib/google/apis/speech_v1/classes.rb', line 895 def @metadata end |
#model ⇒ String
Which model to select for the given request. Select the model best suited to
your domain to get best results. If a model is not explicitly specified, then
we auto-select a model based on the parameters in the RecognitionConfig. *
Model* Description latest_long Best for long form content like media or
conversation. latest_short Best for short form content like commands or single
shot directed speech. command_and_search Best for short queries such as voice
commands or voice search. phone_call Best for audio that originated from a
phone call (typically recorded at an 8khz sampling rate). video Best for audio
that originated from video or includes multiple speakers. Ideally the audio is
recorded at a 16khz or greater sampling rate. This is a premium model that
costs more than the standard rate. default Best for audio that is not one of
the specific audio models. For example, long-form audio. Ideally the audio is
high-fidelity, recorded at a 16khz or greater sampling rate.
medical_conversation Best for audio that originated from a conversation
between a medical provider and patient. medical_dictation Best for audio that
originated from dictation notes by a medical provider.
Corresponds to the JSON property model
915 916 917 |
# File 'lib/google/apis/speech_v1/classes.rb', line 915 def model @model end |
#profanity_filter ⇒ Boolean Also known as: profanity_filter?
If set to true, the server will attempt to filter out profanities, replacing
all but the initial character in each filtered word with asterisks, e.g. "f***"
. If set to false or omitted, profanities won't be filtered out.
Corresponds to the JSON property profanityFilter
922 923 924 |
# File 'lib/google/apis/speech_v1/classes.rb', line 922 def profanity_filter @profanity_filter end |
#sample_rate_hertz ⇒ Fixnum
Sample rate in Hertz of the audio data sent in all RecognitionAudio messages.
Valid values are: 8000-48000. 16000 is optimal. For best results, set the
sampling rate of the audio source to 16000 Hz. If that's not possible, use the
native sample rate of the audio source (instead of re-sampling). This field is
optional for FLAC and WAV audio files, but is required for all other audio
formats. For details, see AudioEncoding.
Corresponds to the JSON property sampleRateHertz
933 934 935 |
# File 'lib/google/apis/speech_v1/classes.rb', line 933 def sample_rate_hertz @sample_rate_hertz end |
#speech_contexts ⇒ Array<Google::Apis::SpeechV1::SpeechContext>
Array of SpeechContext. A means to provide context to assist the speech
recognition. For more information, see speech adaptation.
Corresponds to the JSON property speechContexts
940 941 942 |
# File 'lib/google/apis/speech_v1/classes.rb', line 940 def speech_contexts @speech_contexts end |
#transcript_normalization ⇒ Google::Apis::SpeechV1::TranscriptNormalization
Transcription normalization configuration. Use transcription normalization to
automatically replace parts of the transcript with phrases of your choosing.
For StreamingRecognize, this normalization only applies to stable partial
transcripts (stability > 0.8) and final transcripts.
Corresponds to the JSON property transcriptNormalization
948 949 950 |
# File 'lib/google/apis/speech_v1/classes.rb', line 948 def transcript_normalization @transcript_normalization end |
#use_enhanced ⇒ Boolean Also known as: use_enhanced?
Set to true to use an enhanced model for speech recognition. If use_enhanced
is set to true and the model field is not set, then an appropriate enhanced
model is chosen if an enhanced model exists for the audio. If use_enhanced
is true and an enhanced version of the specified model does not exist, then
the speech is recognized using the standard version of the specified model.
Corresponds to the JSON property useEnhanced
957 958 959 |
# File 'lib/google/apis/speech_v1/classes.rb', line 957 def use_enhanced @use_enhanced end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/google/apis/speech_v1/classes.rb', line 965 def update!(**args) @adaptation = args[:adaptation] if args.key?(:adaptation) @alternative_language_codes = args[:alternative_language_codes] if args.key?(:alternative_language_codes) @audio_channel_count = args[:audio_channel_count] if args.key?(:audio_channel_count) @diarization_config = args[:diarization_config] if args.key?(:diarization_config) @enable_automatic_punctuation = args[:enable_automatic_punctuation] if args.key?(:enable_automatic_punctuation) @enable_separate_recognition_per_channel = args[:enable_separate_recognition_per_channel] if args.key?(:enable_separate_recognition_per_channel) @enable_spoken_emojis = args[:enable_spoken_emojis] if args.key?(:enable_spoken_emojis) @enable_spoken_punctuation = args[:enable_spoken_punctuation] if args.key?(:enable_spoken_punctuation) @enable_word_confidence = args[:enable_word_confidence] if args.key?(:enable_word_confidence) @enable_word_time_offsets = args[:enable_word_time_offsets] if args.key?(:enable_word_time_offsets) @encoding = args[:encoding] if args.key?(:encoding) @language_code = args[:language_code] if args.key?(:language_code) @max_alternatives = args[:max_alternatives] if args.key?(:max_alternatives) @metadata = args[:metadata] if args.key?(:metadata) @model = args[:model] if args.key?(:model) @profanity_filter = args[:profanity_filter] if args.key?(:profanity_filter) @sample_rate_hertz = args[:sample_rate_hertz] if args.key?(:sample_rate_hertz) @speech_contexts = args[:speech_contexts] if args.key?(:speech_contexts) @transcript_normalization = args[:transcript_normalization] if args.key?(:transcript_normalization) @use_enhanced = args[:use_enhanced] if args.key?(:use_enhanced) end |