Class: Google::Apis::SpeechV1::RecognitionMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpeechV1::RecognitionMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/speech_v1/classes.rb,
lib/google/apis/speech_v1/representations.rb,
lib/google/apis/speech_v1/representations.rb
Overview
Description of audio data to be recognized.
Instance Attribute Summary collapse
-
#audio_topic ⇒ String
Description of the content.
-
#industry_naics_code_of_audio ⇒ Fixnum
The industry vertical to which this speech recognition request most closely applies.
-
#interaction_type ⇒ String
The use case most closely describing the audio content to be recognized.
-
#microphone_distance ⇒ String
The audio type that most closely describes the audio being recognized.
-
#original_media_type ⇒ String
The original media the speech was recorded on.
-
#original_mime_type ⇒ String
Mime type of the original audio file.
-
#recording_device_name ⇒ String
The device used to make the recording.
-
#recording_device_type ⇒ String
The type of device the speech was recorded with.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecognitionMetadata
constructor
A new instance of RecognitionMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecognitionMetadata
Returns a new instance of RecognitionMetadata.
1041 1042 1043 |
# File 'lib/google/apis/speech_v1/classes.rb', line 1041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_topic ⇒ String
Description of the content. Eg. "Recordings of federal supreme court hearings
from 2012".
Corresponds to the JSON property audioTopic
997 998 999 |
# File 'lib/google/apis/speech_v1/classes.rb', line 997 def audio_topic @audio_topic end |
#industry_naics_code_of_audio ⇒ Fixnum
The industry vertical to which this speech recognition request most closely
applies. This is most indicative of the topics contained in the audio. Use the
6-digit NAICS code to identify the industry vertical - see https://www.naics.
com/search/.
Corresponds to the JSON property industryNaicsCodeOfAudio
1005 1006 1007 |
# File 'lib/google/apis/speech_v1/classes.rb', line 1005 def industry_naics_code_of_audio @industry_naics_code_of_audio end |
#interaction_type ⇒ String
The use case most closely describing the audio content to be recognized.
Corresponds to the JSON property interactionType
1010 1011 1012 |
# File 'lib/google/apis/speech_v1/classes.rb', line 1010 def interaction_type @interaction_type end |
#microphone_distance ⇒ String
The audio type that most closely describes the audio being recognized.
Corresponds to the JSON property microphoneDistance
1015 1016 1017 |
# File 'lib/google/apis/speech_v1/classes.rb', line 1015 def microphone_distance @microphone_distance end |
#original_media_type ⇒ String
The original media the speech was recorded on.
Corresponds to the JSON property originalMediaType
1020 1021 1022 |
# File 'lib/google/apis/speech_v1/classes.rb', line 1020 def original_media_type @original_media_type end |
#original_mime_type ⇒ String
Mime type of the original audio file. For example audio/m4a, audio/x-alaw-
basic, audio/mp3, audio/3gpp. A list of possible audio mime types is
maintained at http://www.iana.org/assignments/media-types/media-types.xhtml#
audio
Corresponds to the JSON property originalMimeType
1028 1029 1030 |
# File 'lib/google/apis/speech_v1/classes.rb', line 1028 def original_mime_type @original_mime_type end |
#recording_device_name ⇒ String
The device used to make the recording. Examples 'Nexus 5X' or 'Polycom
SoundStation IP 6000' or 'POTS' or 'VoIP' or 'Cardioid Microphone'.
Corresponds to the JSON property recordingDeviceName
1034 1035 1036 |
# File 'lib/google/apis/speech_v1/classes.rb', line 1034 def recording_device_name @recording_device_name end |
#recording_device_type ⇒ String
The type of device the speech was recorded with.
Corresponds to the JSON property recordingDeviceType
1039 1040 1041 |
# File 'lib/google/apis/speech_v1/classes.rb', line 1039 def recording_device_type @recording_device_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/google/apis/speech_v1/classes.rb', line 1046 def update!(**args) @audio_topic = args[:audio_topic] if args.key?(:audio_topic) @industry_naics_code_of_audio = args[:industry_naics_code_of_audio] if args.key?(:industry_naics_code_of_audio) @interaction_type = args[:interaction_type] if args.key?(:interaction_type) @microphone_distance = args[:microphone_distance] if args.key?(:microphone_distance) @original_media_type = args[:original_media_type] if args.key?(:original_media_type) @original_mime_type = args[:original_mime_type] if args.key?(:original_mime_type) @recording_device_name = args[:recording_device_name] if args.key?(:recording_device_name) @recording_device_type = args[:recording_device_type] if args.key?(:recording_device_type) end |