Class: Google::Apis::SpeechV1::SpeechAdaptationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/speech_v1/classes.rb,
lib/google/apis/speech_v1/representations.rb,
lib/google/apis/speech_v1/representations.rb

Overview

Information on speech adaptation use in results

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SpeechAdaptationInfo

Returns a new instance of SpeechAdaptationInfo.



1240
1241
1242
# File 'lib/google/apis/speech_v1/classes.rb', line 1240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adaptation_timeoutBoolean Also known as: adaptation_timeout?

Whether there was a timeout when applying speech adaptation. If true, adaptation had no effect in the response transcript. Corresponds to the JSON property adaptationTimeout

Returns:

  • (Boolean)


1231
1232
1233
# File 'lib/google/apis/speech_v1/classes.rb', line 1231

def adaptation_timeout
  @adaptation_timeout
end

#timeout_messageString

If set, returns a message specifying which part of the speech adaptation request timed out. Corresponds to the JSON property timeoutMessage

Returns:

  • (String)


1238
1239
1240
# File 'lib/google/apis/speech_v1/classes.rb', line 1238

def timeout_message
  @timeout_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1245
1246
1247
1248
# File 'lib/google/apis/speech_v1/classes.rb', line 1245

def update!(**args)
  @adaptation_timeout = args[:adaptation_timeout] if args.key?(:adaptation_timeout)
  @timeout_message = args[:timeout_message] if args.key?(:timeout_message)
end