Class: Google::Apis::SpeechV1::SpeechContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/speech_v1/classes.rb,
lib/google/apis/speech_v1/representations.rb,
lib/google/apis/speech_v1/representations.rb

Overview

Provides "hints" to the speech recognizer to favor specific words and phrases in the results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SpeechContext

Returns a new instance of SpeechContext.



1282
1283
1284
# File 'lib/google/apis/speech_v1/classes.rb', line 1282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boostFloat

Hint Boost. Positive value will increase the probability that a specific phrase will be recognized over other similar sounding phrases. The higher the boost, the higher the chance of false positive recognition as well. Negative boost values would correspond to anti-biasing. Anti-biasing is not enabled, so negative boost will simply be ignored. Though boost can accept a wide range of positive values, most use cases are best served with values between 0 and

  1. We recommend using a binary search approach to finding the optimal value for your use case. Corresponds to the JSON property boost

Returns:

  • (Float)


1266
1267
1268
# File 'lib/google/apis/speech_v1/classes.rb', line 1266

def boost
  @boost
end

#phrasesArray<String>

A list of strings containing words and phrases "hints" so that the speech recognition is more likely to recognize them. This can be used to improve the accuracy for specific words and phrases, for example, if specific commands are typically spoken by the user. This can also be used to add additional words to the vocabulary of the recognizer. See usage limits. List items can also be set to classes for groups of words that represent common concepts that occur in natural language. For example, rather than providing phrase hints for every month of the year, using the $MONTH class improves the likelihood of correctly transcribing audio that includes months. Corresponds to the JSON property phrases

Returns:

  • (Array<String>)


1280
1281
1282
# File 'lib/google/apis/speech_v1/classes.rb', line 1280

def phrases
  @phrases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1287
1288
1289
1290
# File 'lib/google/apis/speech_v1/classes.rb', line 1287

def update!(**args)
  @boost = args[:boost] if args.key?(:boost)
  @phrases = args[:phrases] if args.key?(:phrases)
end