Class: Google::Apis::SpeechV1::SpeechRecognitionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/speech_v1/classes.rb,
lib/google/apis/speech_v1/representations.rb,
lib/google/apis/speech_v1/representations.rb

Overview

A speech recognition result corresponding to a portion of the audio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SpeechRecognitionResult

Returns a new instance of SpeechRecognitionResult.



1365
1366
1367
# File 'lib/google/apis/speech_v1/classes.rb', line 1365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternativesArray<Google::Apis::SpeechV1::SpeechRecognitionAlternative>

May contain one or more recognition hypotheses (up to the maximum specified in max_alternatives). These alternatives are ordered in terms of accuracy, with the top (first) alternative being the most probable, as ranked by the recognizer. Corresponds to the JSON property alternatives



1344
1345
1346
# File 'lib/google/apis/speech_v1/classes.rb', line 1344

def alternatives
  @alternatives
end

#channel_tagFixnum

For multi-channel audio, this is the channel number corresponding to the recognized result for the audio from that channel. For audio_channel_count = N, its output values can range from '1' to 'N'. Corresponds to the JSON property channelTag

Returns:

  • (Fixnum)


1351
1352
1353
# File 'lib/google/apis/speech_v1/classes.rb', line 1351

def channel_tag
  @channel_tag
end

#language_codeString

Output only. The BCP-47 language tag of the language in this result. This language code was detected to have the most likelihood of being spoken in the audio. Corresponds to the JSON property languageCode

Returns:

  • (String)


1358
1359
1360
# File 'lib/google/apis/speech_v1/classes.rb', line 1358

def language_code
  @language_code
end

#result_end_timeString

Time offset of the end of this result relative to the beginning of the audio. Corresponds to the JSON property resultEndTime

Returns:

  • (String)


1363
1364
1365
# File 'lib/google/apis/speech_v1/classes.rb', line 1363

def result_end_time
  @result_end_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1370
1371
1372
1373
1374
1375
# File 'lib/google/apis/speech_v1/classes.rb', line 1370

def update!(**args)
  @alternatives = args[:alternatives] if args.key?(:alternatives)
  @channel_tag = args[:channel_tag] if args.key?(:channel_tag)
  @language_code = args[:language_code] if args.key?(:language_code)
  @result_end_time = args[:result_end_time] if args.key?(:result_end_time)
end