Class: Google::Apis::SpeechV1::SpeechService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::SpeechV1::SpeechService
- Defined in:
- lib/google/apis/speech_v1/service.rb
Overview
Cloud Speech-to-Text API
Converts audio to text by applying powerful neural network models.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://speech.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_custom_class(parent, create_custom_class_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::CustomClass
Create a custom class.
-
#create_phrase_set(parent, create_phrase_set_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::PhraseSet
Create a set of phrase hints.
-
#delete_project_location_custom_class(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::Empty
Delete a custom class.
-
#delete_project_location_phrase_set(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::Empty
Delete a phrase set.
-
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_custom_class(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::CustomClass
Get a custom class.
-
#get_project_location_phrase_set(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::PhraseSet
Get a phrase set.
-
#initialize ⇒ SpeechService
constructor
A new instance of SpeechService.
-
#list_operations(filter: nil, name: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_custom_classes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::ListCustomClassesResponse
List custom classes.
-
#list_project_location_phrase_sets(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::ListPhraseSetResponse
List phrase sets.
-
#longrunningrecognize_speech(long_running_recognize_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::Operation
Performs asynchronous speech recognition: receive results via the google.
-
#patch_project_location_custom_class(name, custom_class_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::CustomClass
Update a custom class.
-
#patch_project_location_phrase_set(name, phrase_set_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::PhraseSet
Update a phrase set.
-
#recognize_speech(recognize_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::RecognizeResponse
Performs synchronous speech recognition: receive results after all audio has been sent and processed.
Constructor Details
#initialize ⇒ SpeechService
Returns a new instance of SpeechService.
47 48 49 50 51 52 |
# File 'lib/google/apis/speech_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-speech_v1', client_version: Google::Apis::SpeechV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/speech_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/speech_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#create_custom_class(parent, create_custom_class_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::CustomClass
Create a custom class.
160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/google/apis/speech_v1/service.rb', line 160 def create_custom_class(parent, create_custom_class_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/customClasses', ) command.request_representation = Google::Apis::SpeechV1::CreateCustomClassRequest::Representation command.request_object = create_custom_class_request_object command.response_representation = Google::Apis::SpeechV1::CustomClass::Representation command.response_class = Google::Apis::SpeechV1::CustomClass command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_phrase_set(parent, create_phrase_set_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::PhraseSet
Create a set of phrase hints. Each item in the set can be a single word or a multi-word phrase. The items in the PhraseSet are favored by the recognition model when you send a call that includes the PhraseSet.
347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/google/apis/speech_v1/service.rb', line 347 def create_phrase_set(parent, create_phrase_set_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/phraseSets', ) command.request_representation = Google::Apis::SpeechV1::CreatePhraseSetRequest::Representation command.request_object = create_phrase_set_request_object command.response_representation = Google::Apis::SpeechV1::PhraseSet::Representation command.response_class = Google::Apis::SpeechV1::PhraseSet command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_custom_class(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::Empty
Delete a custom class.
197 198 199 200 201 202 203 204 205 |
# File 'lib/google/apis/speech_v1/service.rb', line 197 def delete_project_location_custom_class(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::SpeechV1::Empty::Representation command.response_class = Google::Apis::SpeechV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_phrase_set(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::Empty
Delete a phrase set.
380 381 382 383 384 385 386 387 388 |
# File 'lib/google/apis/speech_v1/service.rb', line 380 def delete_project_location_phrase_set(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::SpeechV1::Empty::Representation command.response_class = Google::Apis::SpeechV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/speech_v1/service.rb', line 75 def get_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/operations/{+name}', ) command.response_representation = Google::Apis::SpeechV1::Operation::Representation command.response_class = Google::Apis::SpeechV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_custom_class(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::CustomClass
Get a custom class.
228 229 230 231 232 233 234 235 236 |
# File 'lib/google/apis/speech_v1/service.rb', line 228 def get_project_location_custom_class(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SpeechV1::CustomClass::Representation command.response_class = Google::Apis::SpeechV1::CustomClass command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_phrase_set(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::PhraseSet
Get a phrase set.
415 416 417 418 419 420 421 422 423 |
# File 'lib/google/apis/speech_v1/service.rb', line 415 def get_project_location_phrase_set(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SpeechV1::PhraseSet::Representation command.response_class = Google::Apis::SpeechV1::PhraseSet command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_operations(filter: nil, name: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/google/apis/speech_v1/service.rb', line 120 def list_operations(filter: nil, name: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/operations', ) command.response_representation = Google::Apis::SpeechV1::ListOperationsResponse::Representation command.response_class = Google::Apis::SpeechV1::ListOperationsResponse command.query['filter'] = filter unless filter.nil? command.query['name'] = name unless name.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_custom_classes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::ListCustomClassesResponse
List custom classes.
271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/google/apis/speech_v1/service.rb', line 271 def list_project_location_custom_classes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/customClasses', ) command.response_representation = Google::Apis::SpeechV1::ListCustomClassesResponse::Representation command.response_class = Google::Apis::SpeechV1::ListCustomClassesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_phrase_sets(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::ListPhraseSetResponse
List phrase sets.
458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/google/apis/speech_v1/service.rb', line 458 def list_project_location_phrase_sets(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/phraseSets', ) command.response_representation = Google::Apis::SpeechV1::ListPhraseSetResponse::Representation command.response_class = Google::Apis::SpeechV1::ListPhraseSetResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#longrunningrecognize_speech(long_running_recognize_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::Operation
Performs asynchronous speech recognition: receive results via the google.
longrunning.Operations interface. Returns either an Operation.error or an
Operation.response which contains a LongRunningRecognizeResponse message.
For more information on asynchronous speech recognition, see the how-to.
529 530 531 532 533 534 535 536 537 538 |
# File 'lib/google/apis/speech_v1/service.rb', line 529 def longrunningrecognize_speech(long_running_recognize_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/speech:longrunningrecognize', ) command.request_representation = Google::Apis::SpeechV1::LongRunningRecognizeRequest::Representation command.request_object = long_running_recognize_request_object command.response_representation = Google::Apis::SpeechV1::Operation::Representation command.response_class = Google::Apis::SpeechV1::Operation command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_custom_class(name, custom_class_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::CustomClass
Update a custom class.
306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/google/apis/speech_v1/service.rb', line 306 def patch_project_location_custom_class(name, custom_class_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::SpeechV1::CustomClass::Representation command.request_object = custom_class_object command.response_representation = Google::Apis::SpeechV1::CustomClass::Representation command.response_class = Google::Apis::SpeechV1::CustomClass command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_phrase_set(name, phrase_set_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::PhraseSet
Update a phrase set.
493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/google/apis/speech_v1/service.rb', line 493 def patch_project_location_phrase_set(name, phrase_set_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::SpeechV1::PhraseSet::Representation command.request_object = phrase_set_object command.response_representation = Google::Apis::SpeechV1::PhraseSet::Representation command.response_class = Google::Apis::SpeechV1::PhraseSet command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#recognize_speech(recognize_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SpeechV1::RecognizeResponse
Performs synchronous speech recognition: receive results after all audio has been sent and processed.
560 561 562 563 564 565 566 567 568 569 |
# File 'lib/google/apis/speech_v1/service.rb', line 560 def recognize_speech(recognize_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/speech:recognize', ) command.request_representation = Google::Apis::SpeechV1::RecognizeRequest::Representation command.request_object = recognize_request_object command.response_representation = Google::Apis::SpeechV1::RecognizeResponse::Representation command.response_class = Google::Apis::SpeechV1::RecognizeResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |