Class: Google::Apis::SpeechV1::PhraseSet
- Inherits:
-
Object
- Object
- Google::Apis::SpeechV1::PhraseSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/speech_v1/classes.rb,
lib/google/apis/speech_v1/representations.rb,
lib/google/apis/speech_v1/representations.rb
Overview
Provides "hints" to the speech recognizer to favor specific words and phrases in the results.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Output only.
-
#boost ⇒ Float
Hint Boost.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#expire_time ⇒ String
Output only.
-
#kms_key_name ⇒ String
Output only.
-
#kms_key_version_name ⇒ String
Output only.
-
#name ⇒ String
The resource name of the phrase set.
-
#phrases ⇒ Array<Google::Apis::SpeechV1::Phrase>
A list of word and phrases.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PhraseSet
constructor
A new instance of PhraseSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PhraseSet
Returns a new instance of PhraseSet.
715 716 717 |
# File 'lib/google/apis/speech_v1/classes.rb', line 715 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Output only. Allows users to store small amounts of arbitrary data. Both the
key and the value must be 63 characters or less each. At most 100 annotations.
This field is not used.
Corresponds to the JSON property annotations
629 630 631 |
# File 'lib/google/apis/speech_v1/classes.rb', line 629 def annotations @annotations end |
#boost ⇒ Float
Hint Boost. Positive value will increase the probability that a specific
phrase will be recognized over other similar sounding phrases. The higher the
boost, the higher the chance of false positive recognition as well. Negative
boost values would correspond to anti-biasing. Anti-biasing is not enabled, so
negative boost will simply be ignored. Though boost can accept a wide range
of positive values, most use cases are best served with values between 0 (
exclusive) and 20. We recommend using a binary search approach to finding the
optimal value for your use case as well as adding phrases both with and
without boost to your requests.
Corresponds to the JSON property boost
642 643 644 |
# File 'lib/google/apis/speech_v1/classes.rb', line 642 def boost @boost end |
#delete_time ⇒ String
Output only. The time at which this resource was requested for deletion. This
field is not used.
Corresponds to the JSON property deleteTime
648 649 650 |
# File 'lib/google/apis/speech_v1/classes.rb', line 648 def delete_time @delete_time end |
#display_name ⇒ String
Output only. User-settable, human-readable name for the PhraseSet. Must be 63
characters or less. This field is not used.
Corresponds to the JSON property displayName
654 655 656 |
# File 'lib/google/apis/speech_v1/classes.rb', line 654 def display_name @display_name end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields. This may be sent on update, undelete, and delete requests to
ensure the client has an up-to-date value before proceeding. This field is not
used.
Corresponds to the JSON property etag
662 663 664 |
# File 'lib/google/apis/speech_v1/classes.rb', line 662 def etag @etag end |
#expire_time ⇒ String
Output only. The time at which this resource will be purged. This field is not
used.
Corresponds to the JSON property expireTime
668 669 670 |
# File 'lib/google/apis/speech_v1/classes.rb', line 668 def expire_time @expire_time end |
#kms_key_name ⇒ String
Output only. The KMS key name with which the content of the PhraseSet is encrypted. The
expected format is projects/project/locations/location/keyRings/key_ring
/cryptoKeys/crypto_key`.
Corresponds to the JSON propertykmsKeyName`
676 677 678 |
# File 'lib/google/apis/speech_v1/classes.rb', line 676 def kms_key_name @kms_key_name end |
#kms_key_version_name ⇒ String
Output only. The KMS key version name with which content of the PhraseSet is
encrypted. The expected format is projects/project/locations/location/
keyRings/key_ring/cryptoKeys/crypto_key/cryptoKeyVersions/
crypto_key_version`.
Corresponds to the JSON propertykmsKeyVersionName`
685 686 687 |
# File 'lib/google/apis/speech_v1/classes.rb', line 685 def kms_key_version_name @kms_key_version_name end |
#name ⇒ String
The resource name of the phrase set.
Corresponds to the JSON property name
690 691 692 |
# File 'lib/google/apis/speech_v1/classes.rb', line 690 def name @name end |
#phrases ⇒ Array<Google::Apis::SpeechV1::Phrase>
A list of word and phrases.
Corresponds to the JSON property phrases
695 696 697 |
# File 'lib/google/apis/speech_v1/classes.rb', line 695 def phrases @phrases end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Whether or not this PhraseSet is in the process of being updated.
This field is not used.
Corresponds to the JSON property reconciling
701 702 703 |
# File 'lib/google/apis/speech_v1/classes.rb', line 701 def reconciling @reconciling end |
#state ⇒ String
Output only. The CustomClass lifecycle state. This field is not used.
Corresponds to the JSON property state
707 708 709 |
# File 'lib/google/apis/speech_v1/classes.rb', line 707 def state @state end |
#uid ⇒ String
Output only. System-assigned unique identifier for the PhraseSet. This field
is not used.
Corresponds to the JSON property uid
713 714 715 |
# File 'lib/google/apis/speech_v1/classes.rb', line 713 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 |
# File 'lib/google/apis/speech_v1/classes.rb', line 720 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @boost = args[:boost] if args.key?(:boost) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @expire_time = args[:expire_time] if args.key?(:expire_time) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @kms_key_version_name = args[:kms_key_version_name] if args.key?(:kms_key_version_name) @name = args[:name] if args.key?(:name) @phrases = args[:phrases] if args.key?(:phrases) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) end |